#!/bin/bash -l
#
# CP2K on Piz Daint: 4 nodes, 1 MPI task per node, 12 OpenMP threads per task
#
#SBATCH --job-name=umcm1_ph2
#SBATCH --time=02:00:00
#SBATCH --nodes=2
#SBATCH --ntasks-per-node=1
#SBATCH --cpus-per-task=12
#SBATCH --constraint=gpu
###SBATCH --ntasks-per-core=2
###SBATCH --ntasks-per-node=12
###SBATCH --cpus-per-task=2
#SBATCH --partition=normal
#SBATCH --account=sm18

module load daint-gpu
module load CP2K

export OMP_NUM_THREADS=$SLURM_CPUS_PER_TASK
export CRAY_CUDA_MPS=1

ulimit -s unlimited

export CRAY_CUDA_MPS=1
export OMP_NUM_THREADS=$SLURM_CPUS_PER_TASK

cat > $SLURM_JOB_NAME.inp << EOF
&GLOBAL
  PROJECT $SLURM_JOB_NAME
  RUN_TYPE BSSE ! CELL_OPT
&END GLOBAL

  &EXT_RESTART
     RESTART_FILE_NAME $SLURM_JOB_NAME-1.restart
  &END EXT_RESTART

&FORCE_EVAL
  METHOD Quickstep
  STRESS_TENSOR ANALYTICAL

!! &PROPERTIES
!!  &RESP
!!   USE_REPEAT_METHOD
!!     &SPHERE_SAMPLING
!!       AUTO_VDW_RADII_TABLE UFF
!!     &END
!!  &END RESP
!!&END PROPERTIES

  &DFT
!!  WFN_RESTART_FILE_NAME $SLURM_JOB_NAME-RESTART.wfn

    BASIS_SET_FILE_NAME $HOME/data/BASIS_MOLOPT
    POTENTIAL_FILE_NAME $HOME/data/GTH_POTENTIALS            

    CHARGE 0
    MULTIPLICITY 1

    &MGRID
       CUTOFF [Ry] 450 
    &END

    &QS
       METHOD GPW 
       EPS_DEFAULT 1.0E-10 
    &END

!!  &POISSON
!!     PERIODIC NONE
!!     POISSON_SOLVER MULTIPOLE
!!  &END

    &SCF                              
!!    SCF_GUESS RESTART
      MAX_SCF 30
!!    EPS_SCF 1.0E-6
      !!CHOLESKY OFF
       &OT
      !  ! an accurate preconditioner suitable also for larger systems
        PRECONDITIONER FULL_ALL
        ENERGY_GAP 2E-03
      !  ! the most robust choice (DIIS might sometimes be faster, but not as stable).
        MINIMIZER DIIS
       &END OT

      &OUTER_SCF 
        MAX_SCF 30
!!      EPS_SCF 1.0E-6 ! must match the above
      &END
    &END SCF

    &XC
     &XC_FUNCTIONAL 
         &PBE
           PARAMETRIZATION PBESOL
         &END
     &END XC_FUNCTIONAL
    &END XC
  &END DFT
 
  &SUBSYS
    &CELL 
      A    41.755     0.000     0.000  
      B   -20.903    36.205     0.000  
      C    -0.000     0.000    17.599  
!!    ABC [angstrom] 10. 10. 10.
!!    ALPHA_BETA_GAMMA 90. 90. 90.
!!    SYMMETRY NONE
!!    PERIODIC NONE
    &END CELL
!!  &COORD
!!      Co   10.48250  22.86251   7.78035
!!       C   10.14215  22.57853   6.06741
!!       C    9.57317  22.56637   9.26471
!!       C   11.41959  21.37610   7.98439
!!       O    9.98331  22.48498   4.92056
!!       O    9.02017  22.41505  10.27653
!!       O   11.95192  20.35411   8.12399
!!       C   11.76414  24.10160   7.86573
!!       O   12.64670  24.85633   7.85085
!!       C    8.92300  24.34299   7.49329
!!       C    8.62722  25.33091   8.62208
!!       C    9.59443  26.52689   8.75004
!!       C    9.74350  27.03756  10.19489
!!       C   10.58469  26.09974  11.07856
!!       C   10.68293  26.56602  12.53764
!!       H   11.12334  27.56993  12.61071
!!       H    9.69342  26.61034  13.01271
!!       H   11.30578  25.88896  13.13904
!!       H   11.59109  26.01322  10.64463
!!       H   10.16670  25.08322  11.04797
!!       H    8.75039  27.17936  10.64597
!!       H   10.20920  28.03409  10.18904
!!       H   10.58524  26.25203   8.37097
!!       H    9.24956  27.33840   8.09382
!!       H    8.53795  24.81747   9.58559
!!       H    8.05325  23.71898   7.26848
!!       H    9.22651  24.86523   6.58056
!!       H    7.61229  25.72162   8.42770
!!  &END COORD
    &TOPOLOGY
      COORD_FILE_NAME $SLURM_JOB_NAME.xyz
      COORD_FILE_FORMAT XYZ
    &END
   
    &KIND   H
      BASIS_SET DZVP-MOLOPT-SR-GTH
      POTENTIAL GTH-PBE
    &END KIND
    &KIND   H_GHOST
      BASIS_SET DZVP-MOLOPT-SR-GTH
      GHOST
    &END KIND

    &KIND   C
      BASIS_SET DZVP-MOLOPT-SR-GTH
      POTENTIAL GTH-PBE
    &END KIND
    &KIND   C_GHOST
      BASIS_SET DZVP-MOLOPT-SR-GTH
      GHOST
    &END KIND

    &KIND   N
      BASIS_SET DZVP-MOLOPT-SR-GTH
      POTENTIAL GTH-PBE
    &END KIND
    &KIND   N_GHOST
      BASIS_SET DZVP-MOLOPT-SR-GTH
      GHOST
    &END KIND

    &KIND   O
      BASIS_SET DZVP-MOLOPT-SR-GTH
      POTENTIAL GTH-PBE
    &END KIND
    &KIND   O_GHOST
      BASIS_SET DZVP-MOLOPT-SR-GTH
      GHOST
    &END KIND

    &KIND   P
      BASIS_SET DZVP-MOLOPT-SR-GTH
      POTENTIAL GTH-PBE
    &END KIND
    &KIND   P_GHOST
      BASIS_SET DZVP-MOLOPT-SR-GTH
      GHOST
    &END KIND

    &KIND  Co
      BASIS_SET DZVP-MOLOPT-SR-GTH
      POTENTIAL GTH-PBE
    &END KIND
    &KIND  Co_GHOST
      BASIS_SET DZVP-MOLOPT-SR-GTH
      GHOST
    &END KIND

    &KIND  Zn
      BASIS_SET DZVP-MOLOPT-SR-GTH
      POTENTIAL GTH-PBE
    &END KIND
    &KIND  Zn_GHOST
      BASIS_SET DZVP-MOLOPT-SR-GTH
      GHOST
    &END KIND
  &END SUBSYS
    &BSSE
     &FRAGMENT
        LIST  1..532
     &END FRAGMENT
     &FRAGMENT
        LIST  533..540
     &END FRAGMENT   
  &END BSSE

&END FORCE_EVAL

&MOTION
!!&CONSTRAINT        
!! &FIXED_ATOMS
!!  COMPONENTS_TO_FIX XYZ
!!  LIST 1..7
!! &END
!!&END
  &GEO_OPT
     MAX_DR     1.000E-003
     MAX_FORCE  5.00E-003
     MAX_ITER   350
!!   OPTIMIZER  CG
     RMS_DR     1.00E-002
     RMS_FORCE  1.00E-003
     STEP_START_VAL 0
!!   TYPE TRANSITION_STATE
  &END GEO_OPT

  
  &CELL_OPT
      EXTERNAL_PRESSURE 1. !  0. 0. 1. 0. 0. 1. 0. 0.
      KEEP_ANGLES .TRUE.
      KEEP_SYMMETRY .TRUE.
      MAX_DR	3.00E-003
      MAX_FORCE	4.50E-004
      MAX_ITER  220
!!    OPTIMIZER CG
      PRESSURE_TOLERANCE 1.00E002
      RMS_DR     1.50E-003
      RMS_FORCE  3.00E-004
      STEP_START_VAL 0
      TYPE DIRECT_CELL_OPT 
  &END
&END MOTION

EOF

echo "started"
date

 srun -n $SLURM_NTASKS --ntasks-per-node=$SLURM_NTASKS_PER_NODE -c $SLURM_CPUS_PER_TASK cp2k.psmp -i $SLURM_JOB_NAME.inp -o $SLURM_JOB_NAME.out

echo "ended"
date
